@@ -187,7 +187,7 @@ class Semaphore(
                 next_state: aws_cdk.aws_stepfunctions.State,
                 comments: typing.Optional[builtins.bool] = None,
                 reuse_lock: typing.Optional[builtins.bool] = None,
-                table_read_write_capacity: typing.Optional[typing.Union["TableReadWriteCapacity", typing.Dict[str, typing.Any]]] = None,
+                table_read_write_capacity: typing.Optional[typing.Union[TableReadWriteCapacity, typing.Dict[str, typing.Any]]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -264,7 +264,7 @@ class SemaphoreProps:
                 next_state: aws_cdk.aws_stepfunctions.State,
                 comments: typing.Optional[builtins.bool] = None,
                 reuse_lock: typing.Optional[builtins.bool] = None,
-                table_read_write_capacity: typing.Optional[typing.Union["TableReadWriteCapacity", typing.Dict[str, typing.Any]]] = None,
+                table_read_write_capacity: typing.Optional[typing.Union[TableReadWriteCapacity, typing.Dict[str, typing.Any]]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
